# Generated by Django 2.2.19 on 2021-09-14 18:53

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mellon', '0002_sessionindex'),
    ]

    operations = [
        migrations.CreateModel(
            name='Issuer',
            fields=[
                (
                    'id',
                    models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
                ),
                (
                    'entity_id',
                    models.TextField(unique=True, verbose_name='IdP Entity ID'),
                ),
                ('slug', models.TextField(null=True, unique=True, verbose_name='IdP slug')),
            ],
            options={
                'verbose_name': 'SAML IdP',
                'verbose_name_plural': 'SAML IdPs',
            },
        ),
        migrations.AlterField(
            model_name='usersamlidentifier',
            name='issuer',
            field=models.TextField(null=True, verbose_name='Issuer'),
        ),
        migrations.AddField(
            model_name='usersamlidentifier',
            name='issuer_fk',
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to='mellon.Issuer',
                verbose_name='Issuer',
            ),
        ),
    ]
