# django-mellon - SAML2 authentication for Django
# Copyright (C) 2014-2019 Entr'ouvert
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf.urls import include, url
from django.http import HttpResponse


def homepage(request):
    return HttpResponse('ok')


def context_hook(context):
    context['hook'] = 'HOOK'


urlpatterns = [
    url(
        '^',
        include('mellon.urls'),
        kwargs={
            'template_base': 'theme.html',
            'context_hook': context_hook,
        },
    ),
    url('^$', homepage, name='homepage'),
]
